<?php
class NotExists extends CValidator
{
	/**
	 * @var string path the path to lookup for existance. 
     * WARNING:
	 *	Trailing slash must be included
	 * @example path='protected/uploads/'
	 **/
	public $path;
	/**
	 * @var boolean renameIfExists wheter to rename the attribute if exists. Defaults to true,
         * meaning that if the attributes value (file) already exists this attribute is renamed 
         * and the extension remains the same
         * ex: 
         *      attribute=1.jpg and if the 1.jpg exists then attribute=renamed_to_new_name.jpg
	 **/
	public $renameIfExists=true;
    /**
	 * @var boolean whether the attribute value can be null or empty. Defaults to true,
	 * meaning that if the attribute is empty, it is considered valid.
	 */
     public $allowEmpty=true;
	
    /**
     * @var string message to be show when file exists
     */
    public $existMessage;
    /**
     * @var string message to be shown when file is empty
     */
    public $emptyMessage;
	/**
	 * @var string _extension
	 * holds the extension ex .php
	 * used to rename attribute with extension when renameAttribute is enabled
	 **/
	private $_extension;
	/**
	 * Validates the attribute of the object.
	 * If there is any error, the error message is added to the object.
	 * @param CModel $object the object being validated
	 * @param string $attribute the attribute being validated
	 */
	protected function validateAttribute($object,$attribute){
		$value=$object->$attribute;
                
        if($this->allowEmpty && $this->isEmpty($value))
			return;
        if(!$this->allowEmpty && $this->isEmpty($value)){
                    $message=  $this->emptyMessage!==null?$this->emptyMessage:'{attribute} cannot be blank';
                    $this->addError($object, $attribute, $message);
                    return;
        }
		if(file_exists($this->path.$object->$attribute)){
			if(!$this->renameIfExists){
                            $message=  $this->existMessage!==null?$this->existMessage:'{attribute} {value} already exists';
                            $this->addError($object,$attribute,$message,array('{value}'=>CHtml::encode($value)));
            }
			else{
					$this->_extension='.'.CFileHelper::getExtension($this->path.$value);
					$object->$attribute=md5(microtime().date('mdyHi')).$this->_extension;
					$this->validateAttribute($object,$attribute);
            }
        }
	}
}
	